/***************************************************************
ADOBE SYSTEMS INCORPORATED 
Copyright 2002 Adobe Systems Incorporated 
All Rights Reserved 

NOTICE:  Adobe permits you to use, modify, and distribute this 
file in accordance with the terms of the Adobe license agreement 
accompanying it.  If you have received this file from a source 
other than Adobe, then your use, modification, or distribution
of it requires the prior written permission of Adobe. 
***************************************************************/

/***************************************************************
Author: Ken Villines
***************************************************************/

/***************************************************************

The following script creates a key frame animation effect on 
the currently selected objects. The effect is that of objects
beings typed onto the screen. If arguments are not chosen or 
the argument is null (nothing picked) then the original 
opacity or position will be used. This allows you to have 
static and animated type on effects.  


Function:
	typeon(theObjects, stagger, start_opacity, end_opacity, start_x, start_y, end_x, end_y)

Arguments:
	<theObjects> LMObject - an array of the objects to apply the 
		effect. Does not have to be text objects.  It can be 
		any LMObject.
	<stagger> integer - Amount of time before each object appears
	<start_opacity> integer - the beginning opacity per object
	<end_opacity> integer - the ending opacity per object
	<start_x> integer - the beginning x position per object
	<start_y> integer - the beginning y position per object
	<end_x> integer - the ending x position per object
	<end_y> integer - the ending y position per object

 

***************************************************************/

/***************************************************************
To change the behavior of this script, make your changes below
***************************************************************/

var comp = application.currentComposition;
var myObjects = comp.selection;

typeon(myObjects, 10, 100, 20, 0, 0);

/***************************************************************
DO NOT EDIT BELOW THIS LINE
***************************************************************/

function typeon(theObjects, stagger, start_opacity, end_opacity, start_x, start_y, end_x, end_y)
{ 
	var i; 	
	var startit = (theObjects[0].currentFrame) + stagger;

	for (i = 0; i < theObjects.length; i++) 
	{
		var currentObj = theObjects[i];
		var currentOp = currentObj.opacity;
		var currentX = currentObj.position.x;
		var currentY = currentObj.position.y;
		
		currentObj.startFrame = startit;  //setting the startframe of the object
		currentObj.currentFrame = startit; //setting the current frame of the CTI

		if(start_opacity == null)              //checking to see if argument exists
		{
			currentObj.stopwatch.opacity = true;
			currentObj.opacity = currentOp;	
		}
		else
		{

			var maxVal = Math.max(start_opacity, 100);  //if argument exists check bounds
			var minVal = Math.min(start_opacity, 0);
			if(maxVal <= 100 && minVal >= 0) {
				currentObj.stopwatch.opacity = true;
				currentObj.opacity = start_opacity;
			}
		}
		if(start_x == null) //checking to see if argument exists
		{
			currentObj.stopwatch.position = true;
			currentObj.position.x = currentX;
		}
		else
		{
			currentObj.stopwatch.position = true;
			currentObj.position.x = start_x;	
		}		
		if(start_y == null) //checking to see if argument exists
		{
			currentObj.stopwatch.position = true;
			currentObj.position.y = currentY;
		}
		else
		{
			currentObj.stopwatch.position = true;
			currentObj.position.y = start_y;		
		}

		currentObj.endFrame = startit + stagger; //setting the end frame for the object
		currentObj.currentFrame = startit + stagger; //setting the current frame of the CTI
		currentObj.explicitLifetime = false;

		if(end_opacity == null) //checking to see if argument exists
		{
			currentObj.stopwatch.opacity = true;
			currentObj.opacity = currentOp;
		}
		else
		{
			var maxVal = Math.max(end_opacity, 100);
			var minVal = Math.min(end_opacity, 0);

			if(maxVal <= 100 && minVal >= 0){
				currentObj.stopwatch.opacity = true;
				currentObj.opacity = end_opacity;
			}
		}
		if(end_x == null)  //checking to see if argument exists
		{
			currentObj.stopwatch.position = true;
			currentObj.position.x = currentX;
		}
		else
		{
			currentObj.stopwatch.position = true;
			currentObj.position.x = end_x;		
		}

		if(end_y == null) //checking to see if argument exists
		{
			currentObj.stopwatch.position = true;
			currentObj.position.y = currentY;
		}
		else
		{
			currentObj.stopwatch.position = true;
			currentObj.position.y = end_y;		
		}		
	startit += stagger;
	}
	theObjects[i-1].endFrame = startit;
}

